@@ -1045,13 +1045,6 @@ void GenerateVariableDeclaration<printType, printName>::operator()(Model::Variab
   }
 }
 
-void GenerateToken::operator()(QPair<QString, Model::TerminalItem*> const &__it)
-{
-  Model::TerminalItem *t = __it.second;
-  out << "Token_" << t->mName << " = " << mTokenValue << "," << endl;
-  ++mTokenValue;
-}
-
 void GenerateMemberCode::operator()(Settings::MemberItem* m)
 {
   if ((mKindMask & m->mMemberKind) != 0)
@@ -1069,12 +1062,11 @@ void GenerateMemberCode::operator()(Settings::MemberItem* m)
 
 void GenerateParserDeclarations::operator()()
 {
-  out << "class " << globalSystem.exportMacro << " Parser ";
+  out << "class " << globalSystem.exportMacro << " Parser : ";
   if(!globalSystem.parserBaseClass.isEmpty())
-    out << ": public " << globalSystem.parserBaseClass << " ";
-  out << "{"
+    out << "public " << globalSystem.parserBaseClass << ", ";
+  out << "public TokenTypeWrapper\n{"
       << "public:" << endl
-//       << "typedef " << globalSystem.tokenStream << " tokenStreamType;" << endl
       << "typedef " << globalSystem.tokenStream << "::Token Token;" << endl
       << globalSystem.tokenStream << " *tokenStream;" << endl
       << "int yytoken;" << endl;
@@ -1088,10 +1080,10 @@ void GenerateParserDeclarations::operator()()
            "{}\n};" << endl;
   out << endl
       << "inline Token LA(qint64 k = 1) const" << endl
-      << "{ return tokenStream->token(tokenStream->index() - 1 + k - 1); }"
+      << "{ qint64 idx = tokenStream->index() - 1 + k - 1; qint64 oldidx = tokenStream->index(); tokenStream->rewind(tokenStream->size()); while(idx >= tokenStream->size()) tokenStream->read(); tokenStream->rewind(oldidx); return tokenStream->at(idx); }"
       << endl
       << "inline int yylex() {" << endl
-      << "return (yytoken = tokenStream->nextToken());" << endl
+      << "yytoken = tokenStream->read().kind; return yytoken;" << endl
       << "}" << endl
       << "inline void rewind(qint64 index) {" << endl
       << "tokenStream->rewind(index);" << endl
@@ -1142,18 +1134,6 @@ void GenerateParserDeclarations::operator()()
             << endl;
       }
 
-
-  out << "enum TokenType" << endl << "{" << endl;
-  GenerateToken gen(out);
-  for(World::TerminalSet::iterator it = globalSystem.terminals.begin(); it != globalSystem.terminals.end(); ++it )
-  {
-    gen(qMakePair(it.key(), *it));
-  }
-  out << "TokenTypeSize" << endl
-      << "}; // TokenType" << endl
-      << endl;
-
-
   if (globalSystem.parserclassMembers.declarations.empty() == false)
     {
       out << "// user defined declarations:" << endl;
@@ -1272,11 +1252,10 @@ void GenerateTokenVariableInitialization::visitVariableDeclaration(Model::Variab
 void GenerateTokenTexts::operator()()
 {
   out << "switch (token) {" << endl;
-  GenerateToken gen(out);
   for(World::TerminalSet::iterator it = globalSystem.terminals.begin(); it != globalSystem.terminals.end(); ++it )
   {
     Model::TerminalItem* t = *it;
-    out << "    case Parser::Token_" << t->mName << ":" << endl;
+    out << "    case TokenTypeWrapper::Token_" << t->mName << ":" << endl;
     QString text = t->mDescription;
     text.replace('\\', "\\\\").replace('"', "\\\"");
     out << "        return \"" <<  text << "\";" << endl;
