@@ -27,6 +27,10 @@
 namespace KDevPG
 {
 
+/**
+ * This class is the LL/shunting yard-parser code generator. It generates the actual parsing code.
+ * @todo Investigate whether parts of it are not code-generation, but in fact realy computations which should be handled independently from the output-language.
+ */
 class CodeGenerator: protected DefaultVisitor
 {
 public:
@@ -157,19 +161,6 @@ public:
   virtual void visitVariableDeclaration(Model::VariableDeclarationItem *node);
 };
 
-class GenerateToken
-{
-public:
-  QTextStream& out;
-  int mTokenValue;
-
-public:
-  GenerateToken(QTextStream& o): out(o), mTokenValue(1000)
-  {}
-
-  void operator()(QPair<QString, Model::TerminalItem*> const &__it);
-};
-
 class GenerateMemberCode
 {
 public:
