@@ -1,4 +1,4 @@
-/* This file is part of kdev-pg
+/* This file is part of kdev-pg-qt
    Copyright (C) 2005 Roberto Raggi <roberto@kdevelop.org>
 
    This library is free software; you can redistribute it and/or
@@ -37,6 +37,10 @@ protected:
   {
     globalSystem.env.insert(node->mSymbol, node);
   }
+  virtual void visitInlinedNonTerminal(Model::InlinedNonTerminalItem *node)
+  {
+    Q_UNUSED(node);
+  }
 };
 }
 #endif // KDEV_PG_ENVIRONMENT_H
