@@ -404,9 +404,12 @@ void generateOutput()
 
       << "#ifndef " << language << "_TOKEN_TEXT_H_INCLUDED" << endl
       << "#define " << language << "_TOKEN_TEXT_H_INCLUDED" << endl
-      << endl
-      << "#include \"" << globalSystem.exportMacroHeader << "\"" << endl
-      << "#include \"" << globalSystem.language << "tokentype.h\"" << endl
+      << endl;
+    
+    if (!globalSystem.exportMacroHeader.isEmpty())
+      s << "#include \"" << globalSystem.exportMacroHeader << "\"" << endl;
+    
+    s << "#include \"" << globalSystem.language << "tokentype.h\"" << endl
 
       << "namespace " << globalSystem.ns << "{" << endl
       << endl
@@ -739,6 +742,8 @@ void generateLexer()
       LEXER_CORE_IMPL("read", "start", "if(Base::index() < Base::size())\nreturn Base::read();\n")
     }
     
+    s << globalSystem.lexerBits << endl;
+    
     if(hasStates)
     {
       s << "#undef lxSET_RULE_SET\n" << endl;
@@ -758,8 +763,7 @@ void generateLexer()
          "#undef PP_CONCAT\n"
          "#undef PP_CONCAT_IMPL\n" << endl;
     
-    s << globalSystem.lexerBits << endl
-      << "} // end of namespace " << globalSystem.ns << endl << endl;
+    s << "} // end of namespace " << globalSystem.ns << endl << endl;
     
     QString oname = globalSystem.language;
     oname += "lexer.cpp";
